@@ -23,6 +23,7 @@ from sqlalchemy.orm.exc import MultipleResultsFound, NoResultFound
 from tropofy.database import DBSession
 from tropofy.database.tropofy_orm import json_renderer, DynamicSchemaName
 from tropofy.file_io import FileIoConfig
+from sqlalchemy import create_engine
 
 
 def main(global_config, **settings):
@@ -37,7 +38,7 @@ def main(global_config, **settings):
     # Delay imports, so that DynamicSchemaName.use_app_schemas can be updated correctly before AppDataSet etc. tables are imported.
     from tropofy.app import App, AppDataSet, AppManager, LoadedApps
     from tropofy.widgets import Widget
-    App.overridden_global_sqla_engine = global_sqla_engine
+    App.global_sqla_engine = create_engine(global_sqla_engine)
 
     authn_policy = AuthTktAuthenticationPolicy('sosecret5872', callback=groupfinder, hashalg='sha512')
     authz_policy = ACLAuthorizationPolicy()
@@ -101,6 +102,7 @@ def main(global_config, **settings):
     config.scan(package='tropofy.views')  # Scans for @view_config decorators to register views.
 
     AppManager.add_additional_absolute_paths_to_python_path(settings.get('custom.additional_absolute_paths_to_add_to_python_path'))
+
     AppManager.initialise_apps(settings['custom.apps_directory'])
     for app in LoadedApps.apps.values():
         config.add_static_view('apps_static/%s' % app.url_name, app.app_folder_path, cache_max_age=1)
@@ -109,8 +111,8 @@ def main(global_config, **settings):
 
     transaction.commit()
 
-    if App.overridden_global_sqla_engine:
-        print("You are connecting to a specific database: %s\n" % App.overridden_global_sqla_engine)
+    if App.global_sqla_engine:
+        print("You are connecting to a specific database: %s\n" % App.global_sqla_engine)
 
     app_urls = [app.url_name for app in LoadedApps.apps.values()]
     if len(app_urls) == 1:
