@@ -49,7 +49,7 @@ class AppManager(object):
     @classmethod
     def initialise_apps(cls, apps_dir):
         if DynamicSchemaName.use_app_schemas:
-            cls._create_schema_if_required(create_engine(App.overridden_global_sqla_engine), DynamicSchemaName.COMPUTE_NODE_SCHEMA_NAME)
+            cls._create_schema_if_required(App.global_sqla_engine, DynamicSchemaName.COMPUTE_NODE_SCHEMA_NAME)
 
         for dir_line in apps_dir.split("\n"):
             dirs = [dir_ for dir_ in dir_line.split(";") if os.path.isdir(dir_)]
