@@ -28,7 +28,7 @@ from tropofy.database.tropofy_orm import ORMBase, TropofyDbMetaData
 
 class App(object):
     global_app_indexer = 0
-    overridden_global_sqla_engine = ''
+    global_sqla_engine = None
 
     def __init__(self, config=None):
         self.id = App.global_app_indexer
@@ -41,8 +41,6 @@ class App(object):
         self.step_groups = []
         self.app_folder_path = None  # Needs to be set dynamically after app created. This is to avoid params in constructor.
         self._init_step_groups()
-        self.new_app_config_dict = {"has_none_template": True, "data_set_template_label": "Template"}
-        self.new_app_config_dict.update(self.get_new_dataset_config())
 
     def init_db_engine(self):
         """
@@ -57,8 +55,8 @@ class App(object):
         if self.app_folder_path is None:
             raise AttributeError('self.app_folder_path must be set before App.init_db_engine is called.')
 
-        if App.overridden_global_sqla_engine:
-            self.engine = create_engine(App.overridden_global_sqla_engine)
+        if App.global_sqla_engine:
+            self.engine = App.global_sqla_engine
         else:
             engine_path = os.path.join(self.app_folder_path, self.url_name + ".db")
             self.engine = create_engine("sqlite:///" + engine_path)
@@ -77,16 +75,6 @@ class App(object):
     def get_examples(self):
         return {}
 
-    def get_new_dataset_config(self):
-        """
-        Return a dict of config options for the new dataset form
-        keys:
-            has_none_template- default True, type bool
-            data_set_template_label- default "Template", type string
-        :rtype: dict
-        """
-        return {}
-
     def get_example_app_names(self):
         return [k for k in self.get_examples()]
 
@@ -141,13 +129,6 @@ class App(object):
         ret_config.update(config)
         return ret_config
 
-    def is_for_internal_tropofy_use(self):
-        return self.is_for_internal_tropofy_use()
-
-    def allows_preview_subscription(self):
-        """Anyone can log in to an app and use it with example data if True"""
-        return not self.is_for_internal_tropofy_use()  # Logic matches internal use for now. Corporate private apps etc will return False here.
-
     def add_step_group(self, step_group):
         self.step_groups.append(step_group)
 
@@ -205,6 +186,17 @@ class App(object):
     def get_param(self, name):  # Returns parameter by name. Used by data_set to get parameter.
         return next(param for param in self.get_parameters() if param.name == name)
 
+    def _get_app_init_config(self, **kwargs):
+        """Return config options at the App level. These options are applied to the app on page load (not dynamic beyond this).
+
+        :returns: dict of form: {
+            'disableForcedLinearWorkflow': <bool>,  # Allows users to move to steps in any order.
+        }
+        """
+        return {
+            "disableForcedLinearWorkflow": self.disable_forced_linear_workflow()
+        }
+
 
 class AppWithDataSets(App):
     """Provides an interface for writing a Tropofy App.
@@ -228,6 +220,11 @@ class AppWithDataSets(App):
     """
 
     def __init__(self, config=None):
+        self.new_data_set_config_dict = {
+            "has_none_template": True,
+            "data_set_template_label": "Template",
+        }
+        self.new_data_set_config_dict.update(self.get_new_dataset_config())
         App.__init__(self, config)
 
     def _init_step_groups(self):
@@ -250,6 +247,30 @@ class AppWithDataSets(App):
         """
         pass
 
+    def get_new_dataset_config(self):
+        """
+        Return a dict of config options for the new dataset form
+        keys:
+            has_none_template- default True, type bool
+            data_set_template_label- default "Template", type string
+        :rtype: dict
+        """
+        return {}
+
+    def _get_auto_load_data_set_id(self, **kwargs):
+        try:
+            return self.get_auto_load_data_set_id(**kwargs)
+        except:  # Fails to find auto load data_set_id - don't auto load.
+            return None
+
+    def get_auto_load_data_set_id(self, **kwargs):
+        """Skips the Getting Started page and loads the returned data_set id automatically.
+        :param authenticated_user: the email address of logged in user
+        :return: None, to not auto load data set, or id (int) of an AppDataSet to auto load it.
+
+        """
+        return None
+
     def create_new_data_set_for_user(self, user_email, example_data_set_name, specific_name=''):
         data_set = AppDataSet(self, user_email)
         if specific_name:
@@ -403,6 +424,19 @@ class AppWithDataSets(App):
         return 'Tropofy'
 
 
+
+    def _get_app_init_config(self, **kwargs):
+        """Return config options at the App level. These options are applied to the app on page load (not dynamic beyond this).
+
+        :returns: dict of form: {
+            'disableForcedLinearWorkflow': <bool>,  # Allows users to move to steps in any order.
+        }
+        """
+        app_config = super(AppWithDataSets, self)._get_app_init_config(**kwargs)
+        app_config.update({'autoLoadDataSetId': self._get_auto_load_data_set_id(**kwargs)})
+        return app_config
+
+
 def make_safe_url_name(name):
     return name.lower().replace(' ', '_').replace(',', '')  # Not entirely safe if people do crazy names!
 
@@ -474,11 +508,11 @@ class StepGroup(object):
     def get_unique_div_id(self):  # TODO: Change to properties! (for step and widget also)
         return "step-group-" + str(self.id)
 
-    def serialise(self):
+    def serialise(self, **kwargs):
         return {
             'name': self.name,
             'uniqueDivId': self.get_unique_div_id(),
-            'steps': [step.serialise() for step in self.steps],
+            'steps': [step.serialise(**kwargs) for step in self.steps],
         }
 
 
@@ -562,11 +596,11 @@ class Step(object):
     def get_unique_div_id(self):
         return "step-" + str(self.id)
 
-    def serialise(self):
+    def serialise(self, **kwargs):
         return {
             'name': self.name,
             'uniqueDivId': self.get_unique_div_id(),
             'helpText': self.get_jsonifiable_help_text(),
             'hideNavigation': self.hide_navigation,
-            'widgets': [widget.serialise() for widget in self.get_ordered_widgets()]
+            'widgets': [widget.serialise(**kwargs) for widget in self.get_ordered_widgets()]
         }
