@@ -121,7 +121,7 @@ class AppDataSet(ORMBase):
             try:
                 self._running_task.add_messages(new_messages)
             except AttributeError:  # no attr self._running_task
-                print("Error sending progress messages: {}. Called outside ExecuteFunction widget?.".format([m.text for m in new_messages]))
+                print("Couldn't send progress messages: {}".format([m.text for m in new_messages]))  # Called outside execute function widget?
 
     def current_celery_task_terminated(self):
         return self.query(CeleryTask.terminated_by_user).filter_by(task_id=current_task.request.id).scalar()
@@ -149,18 +149,19 @@ class AppDataSet(ORMBase):
         lines = []
         last_update_time = time.time()
         while subprocess.poll() is None:
-            if self.current_celery_task_terminated():  # TODO: Move into every 2 second loop?
-                subprocess.kill()
-                raise Exception()
+            if current_task:  # Using Celery
+                if self.current_celery_task_terminated():  # TODO: Move into every 2 second loop?
+                    subprocess.kill()
+                    raise Exception()
 
-            try:
-                lines.append(subprocess.stdout.readline()) # This is blocking see http://stackoverflow.com/questions/375427/non-blocking-read-on-a-subprocess-pipe-in-python
-                if time.time() - last_update_time > 2:  # send_progress_message includes a db hit so is a bit slow. Sending less than every 2 seconds is useless, as this is polling frequency.
-                    self.send_progress_message(lines, status=self.message_status.MUTED)
-                    lines = []
-                    last_update_time = time.time()
-            except AttributeError:
-                pass  # subprocess.stdout not set for subprocess.
+                try:
+                    lines.append(subprocess.stdout.readline()) # This is blocking see http://stackoverflow.com/questions/375427/non-blocking-read-on-a-subprocess-pipe-in-python
+                    if time.time() - last_update_time > 2:  # send_progress_message includes a db hit so is a bit slow. Sending less than every 2 seconds is useless, as this is polling frequency.
+                        self.send_progress_message(lines, status=self.message_status.MUTED)
+                        lines = []
+                        last_update_time = time.time()
+                except AttributeError:
+                    pass  # subprocess.stdout not set for subprocess.
 
         try:
             lines += subprocess.stdout.readlines()  # Add remaining lines
@@ -256,7 +257,7 @@ class AppDataSet(ORMBase):
         return obj
 
     def add_all(self, objects):
-        """Adds a list of TropofyBase objects to the Data Set.  The example below
+        """Adds a list of TropofyBase mixins to the Data Set.  The example below
         shows how :func:`add_all` is used,
 
         .. literalinclude:: ../../../tropofy_example_apps/tutorials/tutorial_app_part_5.py
@@ -286,7 +287,7 @@ class AppDataSet(ORMBase):
         :param args: Classes to query, replicates SQLA functionality.
         :type args: Variable number of arguments. Each should be of type :class:`tropofy.app.TropofyBase()` or a Column on such a class. See the `SQLA query docs <http://docs.sqlalchemy.org/en/rel_0_9/orm/query.html#the-query-object>`_ for help.
 
-        :returns: Returns a ``Query`` object populated by with all objects of type ``source_class``
+        :returns: Returns a ``Query`` object populated by with all mixins of type ``source_class``
         """
         return self.db_session().query(*args).filter_by(data_set_id=self.id)
 
