@@ -234,8 +234,9 @@ class ValidationException(Exception):
 
 
 class Validator():
+
     @classmethod
-    def validate(cls, value, type, name):
+    def validate(cls, value, type, name=None):
         '''Validates that 'value' is of type 'type'. Converts if able. 'name' helps give meaningful error msg's.'''        
         validator = cls._get_validator(type)
         if value is not None and validator:
@@ -248,34 +249,22 @@ class Validator():
         if type(validating_type) is type:
             validating_type = validating_type.__name__
 
-        validators = {
-            Integer: Validator._validate_int,
-            Float: Validator._validate_float,
-            Text: Validator._validate_string,
-            Unicode: Validator._validate_string,
-            Date: Validator._validate_date,
-            Time: Validator._validate_time,
-            DateTime: Validator._validate_datetime,
-            Boolean: Validator._validate_boolean,
-            'int': Validator._validate_int,
-            'float': Validator._validate_float,
-            'str': Validator._validate_string,
-            'date': Validator._validate_date,
-            'time': Validator._validate_time,
-            'datetime': Validator._validate_datetime,
-            'bool': Validator._validate_boolean,
-        }
-        return validators.get(validating_type)
+        return type_to_validator_mapping.get(validating_type)
 
     @classmethod
     def _validate_int(cls, value, name):
         if isinstance(value, basestring):
             value = value.replace(',', '')
+        if isinstance(value, float):
+            value = int(round(value))
         if not isinstance(value, int):
             try:
                 value = int(value)
             except:
-                pass
+                try:  # For values such as '1.0'. int('1.0') raises exception. float('1.0') doesn't.
+                    value = int(round(float(value)))
+                except:
+                    pass
         if not isinstance(value, int):
             raise ValidationException(name=name, value=value, message='Expected integer')
         return value
@@ -373,6 +362,25 @@ class Validator():
         return value
 
 
+type_to_validator_mapping = {
+    Integer: Validator._validate_int,
+    Float: Validator._validate_float,
+    Text: Validator._validate_string,
+    Unicode: Validator._validate_string,
+    Date: Validator._validate_date,
+    Time: Validator._validate_time,
+    DateTime: Validator._validate_datetime,
+    Boolean: Validator._validate_boolean,
+    'int': Validator._validate_int,
+    'float': Validator._validate_float,
+    'str': Validator._validate_string,
+    'date': Validator._validate_date,
+    'time': Validator._validate_time,
+    'datetime': Validator._validate_datetime,
+    'bool': Validator._validate_boolean,
+}
+
+
 # this event is called whenever an attribute
 # on a class is instrumented
 @event.listens_for(ORMAncestor, 'attribute_instrument')
