@@ -172,6 +172,13 @@ class Chart(Widget):
 
         .. literalinclude:: ../../../tropofy/widgets/examples/widget_examples.py
            :pyobject: ExampleBarChart.get_table_schema
+
+        Extensions to GoogleCharts:
+
+        - Custom tooltips for Timeline charts. Add a column with role 'tooltip'. eg: "tooltip": ("string", "HoverOver", {'role': 'tooltip'})
+
+
+
         """
         raise NotImplementedError
 
