@@ -27,9 +27,9 @@ class DownloadFileFromUrl(Widget):
     def update_from_db(self, data, data_set_id, oper='', data_set=None):
         return {'url': self.get_file_url(data_set)}
 
-    def serialise(self):
+    def serialise(self, **kwargs):
         '''Join serialisation dict with Widget to get all params needed on client'''
-        return dict(Widget.serialise(self).items() + {
+        return dict(Widget.serialise(self, **kwargs).items() + {
             'buttonText': self.get_export_button_text()
         }.items())
 
