@@ -133,7 +133,7 @@ class Form(Widget):
                         try:
                             self._options.append(Form.Element.Option(**option))
                         except:
-                            raise Form.FormElementException('Could not create Form.Element.Option from %s. You should create Form.Element.Option objects directly in your app. Refer to docs for details.' % option)
+                            raise Form.FormElementException('Could not create Form.Element.Option from %s. You should create Form.Element.Option mixins directly in your app. Refer to docs for details.' % option)
                 if len(self._options) < 1:
                     raise Form.FormElementException("Select element '%s' has no options. Please pass a list of options." % self.name)
 
@@ -243,7 +243,7 @@ class Form(Widget):
 
             - success (optional bool): Indicates full form submit success or failure.
             - message (optional HTML string): Response message for full form submit.
-            - results_list (optional list of dicts of the form): {'name': name, 'success': <bool>, 'message': <str>}.
+            - results (optional list of dicts of the form): {'name': name, 'success': <bool>, 'message': <str>}.
                - name (str): Must match the name of a corresponding :class:`tropofy.widgets.Form.Element`.
                - success (optional bool): defaults to true. Indicates single form element submit success or failure.
                - message (optional str): default to null. Response message for single form element submit.
