@@ -12,12 +12,8 @@ or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
 '''
 
 from sqlalchemy.exc import IntegrityError
-from sqlalchemy.orm import _mapper_registry
-from sqlalchemy.schema import CheckConstraint
-
 from tropofy.widgets import Widget, WidgetConfigException, Form
 from tropofy.database.tropofy_orm import ValidationException
-from tropofy.database import DBSession
 
 
 class GridWidget(Widget):
@@ -63,19 +59,19 @@ class GridWidget(Widget):
             except KeyError:
                 break
 
-        objects, total_records_before_filtering, total_records_after_filtering = self.get_filtered_refresh_objects(
+        rows, total_records_before_filtering, total_records_after_filtering = self.get_filtered_rows(
             data_set=data_set,
             display_start=int(request.POST['start']),
             display_length=int(request.POST['length']),
             global_search_field=request.POST['search[value]'],
             ordered_col_name_sort_direction_tuples=ordered_col_name_sort_direction_tuples,
         )
-        if objects == [] or objects:  # [] means no data in table = OK to proceed. None or something else falsy means an error and shouldn't proceed.
+        if rows == [] or rows:  # [] means no data in table = OK to proceed. None or something else falsy means an error and shouldn't proceed.
             return {
                 'draw': int(request.POST['draw']),  # Suggested to cast to int to protect against cross-site-scripting attacks,
                 'recordsTotal': total_records_before_filtering,
                 'recordsFiltered': total_records_after_filtering,
-                'data': [obj.as_json_data_row(self.get_grids_column_names()) for obj in objects]
+                'data': rows,
             }
 
     def update_to_db(self, data, data_set_id, oper='', data_set=None):
@@ -83,9 +79,9 @@ class GridWidget(Widget):
             self.delete_row(obj_id=data['id'])
         return {'success': True}
 
-    def serialise(self):
+    def serialise(self, **kwargs):
         """Join serialisation dict with Widget to get all params needed on client"""
-        return dict(Widget.serialise(self).items() + {
+        return dict(Widget.serialise(self, **kwargs).items() + {
             'columns': self.get_grids_column_names(),
             'hiddenCols': self.get_hidden_column_names(),
             'descSortedCols': self.get_decs_sorted_cols(),  # Cols default is to sort ascending on init. If in this list they will start sorted descending.
@@ -112,21 +108,12 @@ class GridWidget(Widget):
     def get_hidden_column_names(self):
         return ['id', 'data_set_id']
 
-    def get_refresh_objects(self, data_set):
-        # Todo: Put source_class on GridWidget not SimpleGrid. SimpleGrid source_class must be SQLA class. GridWidget's does not (could be Python class or collections.NamedTuple.
-        # Then, this function must return a set of source_class.
-        # Do this and we can derive:
-        # - GridWidget.get_column_form_input_types
-        # - GridWidget.get_grids_column_names (must match source_class methods). Should probably add option to put labels on these so actual col names in grid change
-        # - GridWidget.get_col_python_type (Doesn't exist yet - probably exists on FormWidget to determine saving add/edit string->python type conversion)
-
-        # What to do about foreign keys? GridWidget shouldn't care! All on FormWidget. FormWidget select type get options & save options.
-        raise NotImplementedError
-
-    def get_filtered_refresh_objects(self, data_set, display_start, display_length, global_search_field, ordered_col_name_sort_direction_tuples):
+    def get_filtered_rows(self, data_set, display_start, display_length, global_search_field, ordered_col_name_sort_direction_tuples):
         """
-        :returns: (list of filtered mixins to display in grid for this page/search, total records in data set before filter, total records in data set after filter)
-        :rtype: tuple - (<object list>, <int>, <int>)
+        Rows returned is a list of lists. Each list represents a row of data in the grid. The elements of the row must be in the same order as the column names.
+
+        :returns: (filtered list of lists of row data to display in grid for this page/search, total records in data set before filter, total records in data set after filter)
+        :rtype: tuple - (<list of lists of data>, <int>, <int>)
         """
         raise NotImplementedError        
 
@@ -139,9 +126,6 @@ class GridWidget(Widget):
     def delete_row(self, obj_id):
         raise NotImplementedError
 
-    def get_table_hierachy_from_inheritance_chain(self):  # This is confusing. Shouldn't live on GridWidget - should be an implementation detail on a subclass.
-        raise NotImplementedError
-
     def get_title(self):
         """Display a title for the grid. Set once for the grid - can not be dynamically changed.
         :rtype: str
@@ -222,48 +206,14 @@ class GridWidget(Widget):
 class CreateUpdateForm(Form):
     def __init__(self, parent_grid_widget):
         self.parent_grid_widget = parent_grid_widget
-
         super(CreateUpdateForm, self).__init__()
 
-    def get_check_constraints_where_column_must_be_in_list_of_values(self, data_set):
-        dict_cons = {}
-        col_names = self._get_query_column_objects().keys()
-        for con in self.parent_grid_widget.source_class.__table__.constraints:
-            if type(con) is CheckConstraint and hasattr(con, 'sqltext') and hasattr(con.sqltext, 'text'):
-                con_text = con.sqltext.text
-                col_name = con_text.split()[0] if con_text.split() and con_text.split()[0] in col_names else None
-                if col_name and con_text.find("in") != -1:
-                    values_text = con_text[con_text.find("(")+1:con_text.find(")")]
-                    dict_cons[col_name] = [v.replace("'", "") for v in values_text.split(",")]
-        return dict_cons
-
-    def get_options_for_column(self, data_set, col_name, hidden_col_names):
-        options = None
-
-        col_name_to_foreign_key_col_objects = {name: col for (name, col) in self._get_query_column_objects().items() if col.foreign_keys and col.name not in hidden_col_names}
-        col_name_to_check_constraint_allowable_values = self.get_check_constraints_where_column_must_be_in_list_of_values(data_set)
-
-        if col_name in col_name_to_foreign_key_col_objects.keys():
-            column = col_name_to_foreign_key_col_objects[col_name]
-            foreign_key_col = list(column.foreign_keys)[0].column
-            mapper = _get_mapper_for_table(foreign_key_col.table)
-
-            if data_set:
-                options_qry = data_set.query(getattr(mapper.class_, foreign_key_col.name))
-            else:
-                options_qry = DBSession().query(getattr(mapper.class_, foreign_key_col.name))
-            options = [Form.Element.Option(v[0]) for v in options_qry]
-
-            if column.nullable:
-                options = [Form.Element.Option(value=None)] + options
-
-        elif col_name in col_name_to_check_constraint_allowable_values.keys() and col_name not in hidden_col_names:
-            options = [Form.Element.Option(v) for v in col_name_to_check_constraint_allowable_values[col_name]]
-
-        return options
+    def get_select_options_for_column(self, data_set, col_name, hidden_col_names):
+        """For a column, get the select options for the form element."""
+        return None
 
     def get_form_elements(self, data_set):
-        if self.parent_grid_widget.editable:  # TODO: Fix Jono's Hack to stop super large foreign key select drop downs loading in non editable grid. Nicer to remove whole form. Nicer again to maybe use typeahead with dynamic options... or something for FK's.
+        if self.parent_grid_widget.grid_is_editable():  # TODO: Fix Jono's Hack to stop super large foreign key select drop downs loading in non editable grid. Nicer to remove whole form. Nicer again to maybe use typeahead with dynamic options... or something for FK's.
             form_elements = []
             non_editable_col_names = self.parent_grid_widget.get_non_editable_cols()
             hidden_col_names = self.parent_grid_widget.get_hidden_column_names()
@@ -271,7 +221,7 @@ class CreateUpdateForm(Form):
                 input_type = self.parent_grid_widget.get_column_name_to_form_input_types().get(name, Form.Element.TEXT)
                 default = self.parent_grid_widget.get_column_name_to_form_default().get(name, None)
 
-                options = self.get_options_for_column(data_set, name, hidden_col_names)
+                options = self.get_select_options_for_column(data_set, name, hidden_col_names)
                 if options:
                     input_type = Form.Element.SELECT
                 form_elements.append(Form.Element(
@@ -303,20 +253,24 @@ class CreateUpdateForm(Form):
             except (ValidationException, IntegrityError) as e:
                 message = e.message
                 success = False
+        self.post_process_data(success, data=data, data_set=data_set)
         return {'success': success, 'message': message}
 
     def is_autosubmit(self, data_set):
         return False
 
-    def _get_query_column_objects(self):  # TODO: This should be on simple grid as specific to SQLA.
-        return {col.name: col for class_type in self.parent_grid_widget.get_table_hierachy_from_inheritance_chain() for col in class_type.__table__.columns}
-
     def get_datetime_display_formats(self):
         return self.parent_grid_widget._get_datetime_display_formats()
 
+    def post_process_data(self, success, data, data_set, **kwargs):
+        """method to custom process data after objects edited, added, or deleted
 
-def _get_mapper_for_table(table):
-    for mapper in list(_mapper_registry):
-        if table in mapper._all_tables:
-            return mapper
-    return None
\ No newline at end of file
+        :param success: whether or not modification was successful
+        :type success: bool
+        :param data: data passed to :func:`tropofy.widgets.grid_widget.grid_widget.CreateUpdateForm.process_data`
+        :param data_set:
+        :type data_set: :class:`tropofy.app.AppDataSet`
+        :param kwargs:
+        :return:
+        """
+        pass
