@@ -12,14 +12,18 @@ or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
 """
 
 from tropofy.database.db_manager import DbManager
-from tropofy.widgets import GridWidget, Form
+from tropofy.widgets import Form
+from tropofy.widgets.grid_widget import grid_widget
 from sqlalchemy.sql.expression import desc, or_, cast
 from sqlalchemy import String
+from sqlalchemy.orm import _mapper_registry
+from sqlalchemy.schema import CheckConstraint
+from tropofy.database import DBSession
 
 
-class SimpleGrid(GridWidget):
+class SimpleGrid(grid_widget.GridWidget):
     """Basic Grid. This widget is special. It is not used like the other widgets. You do not need to create a class
-    which implements function to use an instance of this widget
+    which implements function to use an instance of this widget.
 
     :param source_class: A user defined SQLAlchemy Python class
     :param editable: (Optional - default True). Enables grid to be edited.
@@ -42,7 +46,7 @@ class SimpleGrid(GridWidget):
         self.editable = editable
         super(SimpleGrid, self).__init__(
             title=title,
-            embedded_form_class=embedded_form_class,
+            embedded_form_class=embedded_form_class if embedded_form_class else SimpleGridCreateUpdateForm,
             desc_sort_cols=desc_sort_cols,
             widget_subscriptions=widget_subscriptions
         )
@@ -71,7 +75,7 @@ class SimpleGrid(GridWidget):
     def get_column_name_to_form_input_types(self):
         return {col.name: Form._get_input_type_from_python_type(col.type.python_type) for class_type in self.get_table_hierachy_from_inheritance_chain() for col in class_type.__table__.columns}
 
-    def get_filtered_refresh_objects(self, data_set, display_start, display_length, global_search_field, ordered_col_name_sort_direction_tuples):
+    def get_filtered_rows(self, data_set, display_start, display_length, global_search_field, ordered_col_name_sort_direction_tuples):
         try:
             qry = self.get_qry_of_non_filtered_refresh_objects(data_set)
         except AttributeError:
@@ -94,15 +98,15 @@ class SimpleGrid(GridWidget):
         
         #Order cols
         for col_name, direction in ordered_col_name_sort_direction_tuples:
-            if direction == GridWidget.ASCENDING:
+            if direction == grid_widget.GridWidget.ASCENDING:
                 qry = qry.order_by(getattr(self.source_class, col_name))
-            elif direction == GridWidget.DESCENDING:
+            elif direction == grid_widget.GridWidget.DESCENDING:
                 qry = qry.order_by(desc(getattr(self.source_class, col_name)))
 
         #Reduce to num rows on grid page
         qry = qry.offset(display_start).limit(display_length)
-
-        return qry.all(), total_records_before_filtering, total_records_after_filtering
+        rows = [obj.as_json_data_row(self.get_grids_column_names()) for obj in qry]
+        return rows, total_records_before_filtering, total_records_after_filtering
 
     def get_qry_of_non_filtered_refresh_objects(self, data_set):
         """
@@ -119,3 +123,53 @@ class SimpleGrid(GridWidget):
 
     def grid_is_editable(self):
         return self.editable
+
+
+class SimpleGridCreateUpdateForm(grid_widget.CreateUpdateForm):
+    def get_select_options_for_column(self, data_set, col_name, hidden_col_names):
+        """For a column, get the select options for the form element. For a SimpleGrid - base off of foreign keys on tables."""
+        options = None
+
+        col_name_to_foreign_key_col_objects = {name: col for (name, col) in self._get_query_column_objects().items() if col.foreign_keys and col.name not in hidden_col_names}
+        col_name_to_check_constraint_allowable_values = self.get_check_constraints_where_column_must_be_in_list_of_values(data_set)
+
+        if col_name in col_name_to_foreign_key_col_objects.keys():
+            column = col_name_to_foreign_key_col_objects[col_name]
+            foreign_key_col = list(column.foreign_keys)[0].column
+            mapper = _get_mapper_for_table(foreign_key_col.table)
+
+            if data_set:
+                options_qry = data_set.query(getattr(mapper.class_, foreign_key_col.name))
+            else:
+                options_qry = DBSession().query(getattr(mapper.class_, foreign_key_col.name))
+            options = [Form.Element.Option(v[0]) for v in options_qry]
+
+            if column.nullable:
+                options = [Form.Element.Option(value=None)] + options
+
+        elif col_name in col_name_to_check_constraint_allowable_values.keys() and col_name not in hidden_col_names:
+            options = [Form.Element.Option(v) for v in col_name_to_check_constraint_allowable_values[col_name]]
+
+        return options
+
+    def get_check_constraints_where_column_must_be_in_list_of_values(self, data_set):
+        dict_cons = {}
+        col_names = self._get_query_column_objects().keys()
+        for con in self.parent_grid_widget.source_class.__table__.constraints:
+            if type(con) is CheckConstraint and hasattr(con, 'sqltext') and hasattr(con.sqltext, 'text'):
+                con_text = con.sqltext.text
+                col_name = con_text.split()[0] if con_text.split() and con_text.split()[0] in col_names else None
+                if col_name and con_text.find("in") != -1:
+                    values_text = con_text[con_text.find("(")+1:con_text.find(")")]
+                    dict_cons[col_name] = [v.replace("'", "") for v in values_text.split(",")]
+        return dict_cons
+
+    def _get_query_column_objects(self):
+        return {col.name: col for class_type in self.parent_grid_widget.get_table_hierachy_from_inheritance_chain() for col in class_type.__table__.columns}
+
+
+def _get_mapper_for_table(table):
+    for mapper in list(_mapper_registry):
+        if table in mapper._all_tables:
+            return mapper
+    return None
\ No newline at end of file
