@@ -120,7 +120,7 @@ class Widget(object):
          """
         return str(self.id)
 
-    def serialise(self):
+    def serialise(self, **kwargs):
         '''Dict representation for easy conversion to JSON.'''        
         event_subscriptions = self.event_subscriptions if hasattr(self, 'event_subscriptions') else {}
         serialised_event_subscriptions = {}
@@ -136,7 +136,13 @@ class Widget(object):
             'id': self.id,
             'type': self.get_type(),
             'numColsInGui': self.num_cols_in_gui,
-            'embeddedWidgetSpecs': {key: value.serialise() for key, value in self.embedded_widgets.iteritems()} if hasattr(self, 'embedded_widgets') else {},
+            'embeddedWidgetSpecs': {key: value.serialise(**kwargs) for key, value in self.embedded_widgets.iteritems()} if hasattr(self, 'embedded_widgets') else {},
             'eventSubscriptions': serialised_event_subscriptions,
-            'isHidden': self.is_hidden()
+            'isHidden': self.is_hidden(),
+            'enablePrint': self.enable_print(**kwargs),
         }
+
+    def enable_print(self, **kwargs):
+        """Shows a button on the widget to print it."""
+        # TODO: Make widget accept **kwargs. Then pass a 'printable' option.
+        return False
\ No newline at end of file
