@@ -94,14 +94,14 @@ class SimpleLinearRegressionWithR(AppWithDataSets):
         return {"Demo Data set": load_example_1}
 
     def get_icon_url(self):
-        return 'http://www.tropofy.com/static/css/img/tropofy_example_app_icons/linear_regression.png'
+        return 'https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/linear_regression.png'
 
     def get_home_page_content(self):
         return {
             'content_app_name_header': '''
             <div>
             <span style="vertical-align: middle;">Simple Linear Regression With R</span>
-            <img src="http://www.tropofy.com/static/css/img/tropofy_example_app_icons/linear_regression.png" alt="main logo" style="width:15%">
+            <img src="https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/linear_regression.png" alt="main logo" style="width:15%">
             </div>''',
 
             'content_single_column_app_description': '''
