@@ -264,14 +264,14 @@ class ElectionSummaryApp(AppWithDataSets):
         return [step_group1, step_group2]
 
     def get_icon_url(self):
-        return 'http://www.tropofy.com/static/css/img/tropofy_example_app_icons/election_results_dashboard.png'
+        return 'https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/election_results_dashboard.png'
 
     def get_home_page_content(self):
         return {
             'content_app_name_header': '''
             <div>
             <span style="vertical-align: middle;">Election Results Dashboard</span>
-            <img src="http://www.tropofy.com/static/css/img/tropofy_example_app_icons/election_results_dashboard.png" alt="main logo" style="width:15%">
+            <img src="https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/election_results_dashboard.png" alt="main logo" style="width:15%">
             </div>''',
 
             'content_single_column_app_description': '''
